@@ -1520,10 +1520,14 @@ __all__ = [
     "InstanceProps",
     "RosInstance",
     "RosInstanceProps",
+    "datasource",
 ]
 
 publication.publish()
 
+# Loading modules to ensure their types are registered with the jsii runtime library
+from . import datasource
+
 def _typecheckingstub__cd78668280ac4a751fc1d91a5df3e7ddaec0184a53360ed202e4decb745dfd34(
     scope: _ros_cdk_core_7adfd82f.Construct,
     id: builtins.str,
